@@ -11,6 +11,9 @@ import deskbar, deskbar.interfaces.Module
 import deskbar.interfaces.Match
 import gnomevfs
 import logging
+import threading
+
+LOGGER = logging.getLogger(__name__)
 
 MAX_RESULTS = 20 # per handler
 HANDLERS = ["BeagleLiveHandler"]
@@ -237,7 +240,7 @@ class BeagleLiveMatch (deskbar.interfaces.Match):
                                             )
             self.add_all_actions( actions )
         else:
-            logging.warning("Unknown beagle match type found: "+result["type"] )
+            LOGGER.warning("Unknown beagle match type found: "+result["type"] )
 
         # Load the correct icon
         
@@ -280,13 +283,16 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
         # a new key in inserted and it isn't removed
         # therefore, dict is getting bigger and bigger
         self.counter = {}
+        self.__lock = threading.Lock()
         
     def initialize (self):
         self.beagle = beagle.Client()
    
     def query (self, qstring):
         self.counter[qstring] = {}
+        self.__lock.acquire()
         self.hits = {}
+        self.__lock.release()
         self.beagle_query = beagle.Query()
         self.beagle_query.add_text(qstring)
         self.beagle_query.connect("hits-added", self.hits_added, qstring, MAX_RESULTS)
@@ -296,7 +302,7 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
         hit_matches = []
         for hit in response.get_hits():
             if hit.get_type() not in TYPES:
-                logging.info("Beagle live seen an unknown type:"+ hit.get_type())
+                LOGGER.info("Beagle live seen an unknown type:"+ str(hit.get_type()))
                 continue
             
             if "snippet" in TYPES[hit.get_type()] and TYPES[hit.get_type()]["snippet"]:
@@ -308,7 +314,11 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
                 snippet_request.connect('response', self._on_snippet_received, query, container, qstring, qmax)
                 snippet_request.connect('closed', self._on_snippet_closed, query, container, qstring, qmax)
                 self.beagle.send_request_async(snippet_request)
-                self.hits[hit] = snippet_request
+                try:
+                    self.__lock.acquire()
+                    self.hits[hit] = snippet_request
+                finally:
+                    self.__lock.release()
                 continue
                             
             match = self._on_hit_added(query, hit, qstring, qmax)
@@ -329,10 +339,16 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
         self._on_hit_added(query, container, qstring, qmax)
     
     def _on_snippet_closed(self, request, query, container, qstring, qmax):
-        if container.snippet == None:
-            self._on_hit_added(query, container, qstring, qmax)
-        del self.hits[container.hit]
-        container.hit.unref()
+        try:
+            self.__lock.acquire()
+            # If a snippet request returned from an old query, dismiss it
+            if container.hit in self.hits:
+                if container.snippet == None:
+                    self._on_hit_added(query, container, qstring, qmax)
+                del self.hits[container.hit]
+            container.hit.unref()
+        finally:
+            self.__lock.release()
             
     def _on_hit_added(self, query, hit, qstring, qmax):
         fire_signal = False
