@@ -11,6 +11,7 @@ from deskbar.ui.cuemiac.CuemiacTreeView import CuemiacTreeView
 from deskbar.ui.cuemiac.CuemiacItems import CuemiacCategory
 from deskbar.ui.cuemiac.CuemiacHistory import CuemiacHistoryView
 from deskbar.ui.cuemiac.CuemiacActionsTreeView import CuemiacActionsTreeView, CuemiacActionsModel
+from deskbar.ui.cuemiac.LingeringSelectionWindow import LingeringSelectionWindow
 
 class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
     """
@@ -32,6 +33,7 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.set_title("Deskbar Applet")
         self.set_default_size( self._model.get_window_width(), -1 )
         self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
+        self.set_role("deskbar-search-window")
         self.set_property("skip-taskbar-hint", True)
 
         self._model.connect("query-ready", lambda s,m: gobject.idle_add(self.append_matches, s, m))
@@ -103,6 +105,8 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.cview.connect ("row-collapsed", self._controller.on_category_collapsed, self.treeview_model)
         self.cview.show()
         
+        LingeringSelectionWindow (self.cview)
+        
         self.scrolled_results = gtk.ScrolledWindow ()
         self.scrolled_results.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.scrolled_results.set_shadow_type(gtk.SHADOW_IN)
@@ -118,6 +122,8 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.aview.connect ("go-back", self.__on_go_back)
         self.aview.show()
         
+        LingeringSelectionWindow (self.aview)
+        
         self.scrolled_actions = gtk.ScrolledWindow()
         self.scrolled_actions.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.scrolled_actions.set_shadow_type(gtk.SHADOW_IN)
@@ -143,6 +149,9 @@ class CuemiacWindowView(deskbar.interfaces.View, gtk.Window):
         self.results_box.pack_start(self.scrolled_results)
         self.results_box.pack_start(self.actions_box)
         self.vbox_main.pack_start(self.results_box)
+   
+    def __on_row_act(self, view, path, column):
+        print "======================"
     
     def clear_all(self):
         deskbar.interfaces.View.clear_all(self)
